from representatives.management.remove_command import RemoveCommand

from representatives.models import Representative


class Command(RemoveCommand):
    manager = Representative.objects
    conditions = {'votes': None}



from django.conf.urls import include, url

from rest_framework import routers

from representatives_votes.api import (
    DossierViewSet,
    ProposalViewSet,
    VoteViewSet,
)

from representatives.api import (
    ConstituencyViewSet,
    GroupViewSet,
    MandateViewSet,
    RepresentativeViewSet,
)

router = routers.DefaultRouter()
router.register(r'constituencies', ConstituencyViewSet)
router.register(r'groups', GroupViewSet)
router.register(r'mandates', MandateViewSet)
router.register(r'representatives', RepresentativeViewSet)
router.register(r'dossiers', DossierViewSet)
router.register(r'proposals', ProposalViewSet)
router.register(r'votes', VoteViewSet)

urlpatterns = [
    url(r'api/', include(router.urls)),
]



from representatives.management.remove_command import RemoveCommand

from representatives_votes.models import Dossier


class Command(RemoveCommand):
    manager = Dossier.objects
    conditions = {'proposals': None}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('representatives_votes', '0007_vote_unique_together_proposal_representative'),
    ]

    operations = [
        migrations.AlterField(
            model_name='proposal',
            name='title',
            field=models.CharField(unique=True, max_length=1000),
        ),
    ]
